@@ -3,10 +3,14 @@ package NeedsOpenSSL;
 use strict;
 use warnings;
 
+use parent qw(TestClass);
+
 use Test::More;
 
 use File::Which ();
 
+use OpenSSL_Control ();
+
 sub SKIP_CLASS {
     my ($self) = @_;
 
@@ -19,11 +23,11 @@ sub _get_openssl {
     my ($self) = @_;
 
     return $self->{'_ossl_bin'} ||= do {
-        my $bin = File::Which::which('openssl');
+        my $bin = OpenSSL_Control::openssl_bin();
 
         if ($bin) {
             note "Using OpenSSL binary: $bin";
-            note `$bin version -a`;
+            note OpenSSL_Control::run(qw(version -a));
         }
 
         $bin;
